@@ -95,6 +95,8 @@ fbCanGetSolid(PicturePtr pict)
     case PICT_x8r8g8b8:
     case PICT_a8b8g8r8:
     case PICT_x8b8g8r8:
+    case PICT_b8g8r8a8:
+    case PICT_b8g8r8x8:
     case PICT_r8g8b8:
     case PICT_b8g8r8:
     case PICT_r5g6b5:
@@ -383,7 +385,7 @@ typedef struct _FbComposeData {
     CARD16	height;
 } FbComposeData;
 
-void
+extern _X_EXPORT void
 fbCompositeRect (const FbComposeData *data, CARD32 *scanline_buffer);
 
 typedef FASTCALL void (*CombineMaskU) (CARD32 *src, const CARD32 *mask, int width);
@@ -398,7 +400,7 @@ typedef struct _FbComposeFunctions {
 
 /* fbcompose.c */
 
-void
+extern _X_EXPORT void
 fbCompositeGeneral (CARD8	op,
 		    PicturePtr	pSrc,
 		    PicturePtr	pMask,
@@ -413,7 +415,7 @@ fbCompositeGeneral (CARD8	op,
 		    CARD16	height);
 
 /* fbpict.c */
-void
+extern _X_EXPORT void
 fbComposite (CARD8      op,
 	     PicturePtr pSrc,
 	     PicturePtr pMask,
@@ -440,7 +442,7 @@ typedef void	(*CompositeFunc) (CARD8      op,
 				  CARD16     width,
 				  CARD16     height);
 
-void
+extern _X_EXPORT void
 fbWalkCompositeRegion (CARD8 op,
 		       PicturePtr pSrc,
 		       PicturePtr pMask,
@@ -459,20 +461,20 @@ fbWalkCompositeRegion (CARD8 op,
 
 /* fbtrap.c */
 
-void
+extern _X_EXPORT void
 fbAddTraps (PicturePtr	pPicture,
 	    INT16	xOff,
 	    INT16	yOff,
 	    int		ntrap,
 	    xTrap	*traps);
 
-void
+extern _X_EXPORT void
 fbRasterizeTrapezoid (PicturePtr    alpha,
 		      xTrapezoid    *trap,
 		      int	    x_off,
 		      int	    y_off);
 
-void
+extern _X_EXPORT void
 fbAddTriangles (PicturePtr  pPicture,
 		INT16	    xOff,
 		INT16	    yOff,
